@@ -8,7 +8,7 @@
 #######################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.1-1'
+Version = '0.3-1'
 
 import os
 import sys
@@ -21,11 +21,14 @@ from CSSUfeaturesUI import *
 
 ##############################################################
 
-PathApp       = '/opt/CSSUfeatures'            # application path
-PathSystem    = '/usr/share/hildon-desktop/'    # main path
-ConfigSystem  = 'transitions.ini'               # name of system config file
-PathTemp      = '/home/user/.CSSUfeatures/'     # temp path of files
-ConfigTemp    = 'CSSUfeatures_temp'             # name of temp config file
+PathApp             = '/opt/CSSUfeatures'             # application path
+PathSystem          = '/usr/share/hildon-desktop/'    # main path
+ConfigSystem        = 'transitions.ini'               # name of system config file
+PathTheme           = '/etc/hildon/theme/'            # main path (if themes are in place)
+ConfigTheme         = 'transitions.ini'               # name of system config file (if themes are in place)
+PathTemp            = '/home/user/.CSSUfeatures/'     # temp path of files
+ConfigTempSystem    = 'CSSUfeatures_temp_system'      # name of temp config file from/for system
+ConfigTempTheme     = 'CSSUfeatures_temp_theme'       # name of temp config file from/for theme
 
 ##############################################################
 
@@ -55,13 +58,24 @@ def showQuickMessage(message):
                /org/freedesktop/Notifications \
                org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
-
-def doUpdateConfig():            
-    ''' Update the config file with the edited. '''
+               
+def doUpdateConfigSystem():            
+    ''' Update the config file of the system with the edited. '''
 
     time.sleep(1)
     try:
-       os.system('sudo %s/updateTransitions copyTemp' % PathApp)
+       os.system('sudo %s/updateTransitions copyTempSystem' % PathApp)
+    except:
+       return False
+    else: 
+       return True
+
+def doUpdateConfigTheme():            
+    ''' Update the config file of the theme with the edited. '''
+
+    time.sleep(1)
+    try:
+       os.system('sudo %s/updateTransitions copyTempTheme' % PathApp)
     except:
        return False
     else: 
@@ -194,19 +208,33 @@ class MyMainWindow(QtGui.QMainWindow):
              
         def doSetCurrent(self): ##FIXME: implement method!!!    
              ''' Set CURRENT values in the GUI''' 
+           
+             #self.ui.comboBox.setCurrentIndex(zoom_on_press)
+             #self.ui.comboBox.setCurrentIndex(parallax)
+             #self.ui.comboBox.setCurrentIndex(blurless)
+             #self.ui.comboBox.setCurrentIndex(taskswitcher)
+             #self.ui.comboBox.setCurrentIndex(zaxisrotation)
+             #self.ui.comboBox.setCurrentIndex(forcerotation)
+             #self.ui.comboBox.setCurrentIndex(tactilepopups)
              
              message = 'Displaying the CURRENT configuration options feature is not yet implemented.'
              showMessage(message)
-             #message = 'The CURRENT configuration options are shown.'
-             #showQuickMessage(message)
+             # message = 'The CURRENT configuration options are shown.'
+             # showQuickMessage(message)
 
         def doSetDefault(self): ##FIXME: implement method!!!    
              ''' Set DEFAULT values in the GUI''' 
+
+             self.ui.comboBoxBlurless.setCurrentIndex(0)
+             self.ui.comboBoxTaskSwitcher.setCurrentIndex(0)
+             self.ui.comboBoxRotationAxis.setCurrentIndex(0)
+             self.ui.comboBoxForcedRotation.setCurrentIndex(0)
+             self.ui.comboBoxTactile.setCurrentIndex(0)
+             self.ui.comboBoxZoomPress.setCurrentIndex(0)
+             self.ui.lineEditParallax.setText('1.3')
              
-             message = 'Displaying the DEFAULT configuration options feature is not yet implemented.'
-             showMessage(message)
-             #message = 'The DEFAULT configuration options are shown.'
-             #showQuickMessage(message)
+             message = 'The DEFAULT configuration options are shown.'
+             showQuickMessage(message)
              
         def doCreateConfig(self):        
              ''' Create the new configuration file'''
@@ -223,10 +251,10 @@ class MyMainWindow(QtGui.QMainWindow):
              ZoomPress       = self.ui.comboBoxZoomPress.currentIndex()
              Parallax        = self.ui.lineEditParallax.text()
 
-             #Update of the config file.
-             os.rename( PathTemp + ConfigTemp, PathTemp + ConfigTemp + "~" )
-             destination = open( PathTemp + ConfigTemp, "w" )
-             source = open( PathTemp + ConfigTemp + "~", "r" )
+             #Update of the System config file.
+             os.rename( PathTemp + ConfigTempSystem, PathTemp + ConfigTempSystem + "~" )
+             destination = open( PathTemp + ConfigTempSystem, "w" )
+             source = open( PathTemp + ConfigTempSystem + "~", "r" )
              for Line in source:
                  if   Line.startswith("zoom_on_press"):
                      destination.write('zoom_on_press = %s\n' % ZoomPress)
@@ -247,10 +275,41 @@ class MyMainWindow(QtGui.QMainWindow):
              source.close()
              destination.close()
 
-             message = 'Updating. Please wait..'
+             message = 'Updating system files. Please wait..'
              showQuickMessage(message)
-             doUpdateConfig()
-             message = 'The settings have been successfully saved.'
+
+             doUpdateConfigSystem()
+             message = 'The new settings have been successfully saved.'
+             
+             #Update of the Theme config file (if it exists).
+             if CheckFile(PathTheme,ConfigTheme) == True:
+
+                 os.rename( PathTemp + ConfigTempTheme, PathTemp + ConfigTempTheme + "~" )
+                 destination = open( PathTemp + ConfigTempTheme, "w" )
+                 source = open( PathTemp + ConfigTempTheme + "~", "r" )
+                 for Line in source:
+                     if   Line.startswith("zoom_on_press"):
+                         destination.write('zoom_on_press = %s\n' % ZoomPress)
+                     elif Line.startswith("parallax"):
+                         destination.write('parallax = %s\n' % Parallax)
+                     elif Line.startswith("blurless"):
+                         destination.write('blurless = %s\n' % Blurless)
+                     elif Line.startswith("taskswitcher"):
+                        destination.write('taskswitcher = %s\n' % TaskSwitcher)
+                     elif Line.startswith("zaxisrotation"):
+                        destination.write('zaxisrotation = %s\n' % RotationAxis)
+                     elif Line.startswith("forcerotation"):
+                        destination.write('forcerotation = %s\n' % ForcedRotation)
+                     elif Line.startswith("tactilepopups"):
+                        destination.write('tactilepopups = %s\n' % Tactile)
+                     else: 
+                        destination.write( Line )
+                 source.close()
+                 destination.close()
+             
+                 doUpdateConfigTheme()
+                 message = 'The new settings have been successfully saved to the system and theme folders.'
+
              showMessage(message)
             
 if __name__ == "__main__":
@@ -267,8 +326,12 @@ if __name__ == "__main__":
     else:
         pass
     
-    os.system('cp %s %s' % (PathSystem + ConfigSystem, PathTemp + ConfigTemp))
-
+    os.system('cp %s %s' % (PathSystem + ConfigSystem, PathTemp + ConfigTempSystem))
+    if CheckFile(PathTheme,ConfigTheme) == True: 
+        os.system('cp %s %s' % (PathTheme + ConfigTheme, PathTemp + ConfigTempTheme))
+        message = 'INFO: The application found a settings file in the theme folder.\nThe application will update both system and theme files with any changes requested.'
+        showMessage(message)
+        
     ##Open Dialog Window
     app = QtGui.QApplication(sys.argv)
     myapp = MyMainWindow()
